(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51866,       1403]*)
(*NotebookOutlinePosition[     81033,       2471]*)
(*  CellTagsIndexPosition[     80989,       2467]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Continuation from file 2004-08-03-A.PartI.ppt", "Text"],

Cell[CellGroupData[{

Cell["\<\
The Importance of Formal Methods
in Mathematics\
\>", "Subtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
Bruno Buchberger
RISC and RICAM, Linz, Austria

Talk at Workshop on Computer Algebra
RIMS, Kyoto University
August 3, 2004
\
\>", "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Copyright",
    FontWeight->"Bold"],
  " Bruno Buchberger 2004\n\n",
  StyleBox["Copyright Note:  ",
    FontWeight->"Bold"],
  "This file may be copied and stored under the following conditions:\n\n-  \
the file must be kept unchanged including the copyright note\n-  a mail must \
be send to buchberger@risc.uni-linz.ac.at\n-  if material of this talk is \
used the talk must be cited approrpiately."
}], "Text"],

Cell[CellGroupData[{

Cell["Algorithm Synthesis", "Section"],

Cell[CellGroupData[{

Cell["The Algorithm Invention (\"Synthesis\") Problem", "Subsection"],

Cell["\<\
Given a problem specification P (in predicate logic) find an algorithm A such \
that\
\>", "Text"],

Cell[BoxData[
    \(\[ForAll] \+x\(\( P[x, A[x]]\)\(.\)\)\)], "Input"],

Cell["Higher \"order\": Find an algorithm (\"method\") S such that", "Text"],

Cell[BoxData[
    \(\[ForAll] \+P\ \ \ \ \ \(\[ForAll] \+x\(\( P[
            x, \ \(S[P]\)\ [x]]\)\(.\)\)\)\)], "Input"],

Cell["Examples of specifications P:", "Text"],

Cell[BoxData[{
    \(P[x, y]\  \[DoubleLeftRightArrow] \ is\[Dash]greater[x, y]\), "\n", 
    \(P[x, y]\  \[DoubleLeftRightArrow] \ 
      is\[Dash]sorted\[Dash]version[x, y]\), "\n", 
    \(P[x, y]\  \[DoubleLeftRightArrow] \ 
      has\[Dash]derivative[x, y]\), "\n", 
    \(P[x, y]\  \[DoubleLeftRightArrow] \ 
      are\[Dash]factors\[Dash]of[x, y]\), "\n", 
    \(P[x, y]\  \[DoubleLeftRightArrow] \ 
      is\[Dash]Gr\[ODoubleDot]bner\[Dash]basis[x, 
        y]\), "\[IndentingNewLine]", 
    \(\(\(...\)\(.\)\)\)}], "Input"],

Cell["\<\
A general algorithm S for \"all\" P cannot exist.

There is a rich literature on synthesis algorithms (methods) for special \
instances of the problem,

including methods in software technology, e.g. \"component-based \
programming\".\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Project"
}], "Subsection"],

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " project [BB et al. 1996 ...]  aims at computer-support of all phases of \
mathematical activity:"
}], "Text"],

Cell[" invention of notions", "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{60.625, Inherited}, {Inherited, Inherited}}],

Cell[" invention and proof of propositions", "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{60.625, Inherited}, {Inherited, Inherited}}],

Cell[" invention of problems", "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{60.625, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  " ",
  StyleBox["invention and proof of algorithms",
    FontColor->RGBColor[0, 0, 1]],
  " (the subject of this talk)"
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{60.625, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language is a version of predicate logic. "
}], "Text"],

Cell[TextData[{
  "A sublanguage of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " language is a programming language."
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system is implemented in Mathematica."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\"Lazy Thinking\": An Algorithm for Algorithm Synthesis", "Section"],

Cell[CellGroupData[{

Cell["The \"Lazy Thinking\" Method [BB 2001]", "Subsection"],

Cell["Given a problem specification P", "Text"],

Cell[TextData[{
  "consider various \"",
  StyleBox["algorithm schemes",
    FontColor->RGBColor[0, 0, 1]],
  "\" for A"
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{45.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "and try to ",
  StyleBox["prove ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["(automatically)",
    FontColor->RGBColor[1, 0, 0]],
  " ",
  Cell[BoxData[
      \(\[ForAll] \+x\(\( P[x, A[x]]\)\(.\)\)\)]]
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{45.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "This proof will normally ",
  StyleBox["fail",
    FontColor->RGBColor[0, 0, 1]],
  " because nothing is known on the auxiliary functions in the algorithm \
scheme."
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{45.5, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "From the temporary assumptions and goals in the failing proof situation ",
  StyleBox["(automatically)",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" generate specifications for the auxiliary functions",
    FontColor->RGBColor[0, 0, 1]],
  " that would make the proof possible."
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{45.5, Inherited}, {Inherited, Inherited}}],

Cell["\<\
Now, apply the method recursively to the auxiliary functions.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Synthesis of Merge-Sort [BB et al. 2003]", "Subsection"],

Cell["Problem: Synthesize A such that ", "Text"],

Cell[BoxData[
    \(\[ForAll] \+x\(\( is\[Dash]sorted\[Dash]version[x, 
          A[x]]\)\(.\)\)\)], "Input"],

Cell["Example of algorithm scheme: \"divide and conquer\"", "Text"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+x\), 
      RowBox[{"(", 
        RowBox[{\(A[x]\), "=", 
          RowBox[{"{", GridBox[{
                {
                  RowBox[{
                    StyleBox["s",
                      FontFamily->"Eras Bold ITC",
                      FontColor->RGBColor[1, 0, 0]], "[", "x", "]"}], 
                  "\[DoubleLeftArrow]", \(is\[Dash]trivial\[Dash]tuple[x]\)},
                {
                  RowBox[{
                    StyleBox["m",
                      FontFamily->"Eras Bold ITC",
                      FontColor->RGBColor[1, 0, 0]], "[", 
                    RowBox[{
                      RowBox[{"A", "[", 
                        RowBox[{
                          StyleBox["l",
                            FontFamily->"Eras Bold ITC",
                            FontColor->RGBColor[1, 0, 0]], "[", "x", "]"}], 
                        "]"}], ",", 
                      RowBox[{"A", "[", 
                        RowBox[{
                          StyleBox["r",
                            FontFamily->"Eras Bold ITC",
                            FontColor->RGBColor[1, 0, 0]], "[", "x", "]"}], 
                        "]"}]}], "]"}], "\[DoubleLeftArrow]", "otherwise"}
                },
              ColumnAlignments->{Left}], 
            StyleBox["}",
              ShowContents->False]}]}], ")"}]}]], "Input"],

Cell[TextData[{
  "Lazy Thinking ",
  StyleBox["automatically",
    FontColor->RGBColor[0, 0, 1]],
  " (in approx. 2 minutes on a laptop), using the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, finds the following specifications for the auxiliary functions"
}], "Text"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+x\), 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            StyleBox["s",
              FontFamily->"Eras Bold ITC",
              FontColor->RGBColor[1, 0, 0]], "[", "x", "]"}], "=", "x"}], 
        ")"}]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+\(y, z\)\), 
      RowBox[{"(", 
        RowBox[{GridBox[{
              {\(is\[Dash]sorted[y]\)},
              {\(is\[Dash]sorted[z]\)}
              },
            ColumnAlignments->{Left}], " ", "\[Implies]", GridBox[{
              {
                RowBox[{"is\[Dash]sorted", "[", 
                  RowBox[{
                    StyleBox["m",
                      FontFamily->"Eras Bold ITC",
                      FontColor->RGBColor[1, 0, 0]], "[", \(y, z\), "]"}], 
                  "]"}]},
              {
                RowBox[{
                  RowBox[{
                    StyleBox["m",
                      FontFamily->"Eras Bold ITC",
                      FontColor->RGBColor[1, 0, 0]], "[", \(y, z\), "]"}], 
                  " ", "\[TildeTilde]", " ", \((y \[CupCap] z)\)}]}
              },
            ColumnAlignments->{Left}]}], " ", ")"}]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+x\), 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            StyleBox["l",
              FontFamily->"Eras Bold ITC",
              FontColor->RGBColor[1, 0, 0]], "[", "x", "]"}], "\[CupCap]", 
          RowBox[{
            StyleBox["r",
              FontFamily->"Eras Bold ITC",
              FontColor->RGBColor[1, 0, 0]], "[", "x", "]"}], " ", 
          "\[TildeTilde]", "  ", "x"}], ")"}]}]], "Input"],

Cell[TextData[{
  "Note: All these algorithms are formulae in (",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ") predicate logic ",
  StyleBox["and",
    FontColor->RGBColor[0, 0, 1]],
  " are executable within the same logic!"
}], "Text"],

Cell[TextData[{
  StyleBox["Acknowledgement",
    FontWeight->"Bold"],
  ": My co-workers A. Craciun, W. Windsteiger, et al."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["What to Do with the Synthesized Sub-specifications ?", "Subsection"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+x\), 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            StyleBox["s",
              FontFamily->"Eras Bold ITC",
              FontColor->RGBColor[1, 0, 0]], "[", "x", "]"}], "=", "x"}], 
        ")"}]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+\(y, z\)\), 
      RowBox[{"(", 
        RowBox[{GridBox[{
              {\(is\[Dash]sorted[y]\)},
              {\(is\[Dash]sorted[z]\)}
              },
            ColumnAlignments->{Left}], " ", "\[Implies]", GridBox[{
              {
                RowBox[{"is\[Dash]sorted", "[", 
                  RowBox[{
                    StyleBox["m",
                      FontFamily->"Eras Bold ITC",
                      FontColor->RGBColor[1, 0, 0]], "[", \(y, z\), "]"}], 
                  "]"}]},
              {
                RowBox[{
                  RowBox[{
                    StyleBox["m",
                      FontFamily->"Eras Bold ITC",
                      FontColor->RGBColor[1, 0, 0]], "[", \(y, z\), "]"}], 
                  " ", "\[TildeTilde]", " ", \((y \[CupCap] z)\)}]}
              },
            ColumnAlignments->{Left}]}], " ", ")"}]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+x\), 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            StyleBox["l",
              FontFamily->"Eras Bold ITC",
              FontColor->RGBColor[1, 0, 0]], "[", "x", "]"}], "\[CupCap]", 
          RowBox[{
            StyleBox["r",
              FontFamily->"Eras Bold ITC",
              FontColor->RGBColor[1, 0, 0]], "[", "x", "]"}], " ", 
          "\[TildeTilde]", "  ", "x"}], ")"}]}]], "Input"],

Cell[TextData[{
  "either there are ",
  StyleBox["s, m, l, r  ",
    FontColor->RGBColor[1, 0, 0]],
  "with these specifications in the algorithm library\n(\"",
  StyleBox["algorithm retrieval",
    FontColor->RGBColor[0, 0, 1]],
  "\")"
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{66, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "or there are ",
  StyleBox["s, m, l, r ",
    FontColor->RGBColor[1, 0, 0]],
  "in the algorithm library for which these specifications can be \
(automatically) proved (\"",
  StyleBox["algorithm verification",
    FontColor->RGBColor[0, 0, 1]],
  "\")"
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{66, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "or ",
  StyleBox["s, m, l, r ",
    FontColor->RGBColor[1, 0, 0]],
  "can by synthesized by applying the method again (\"",
  StyleBox["algorithm synthesis",
    FontColor->RGBColor[0, 0, 1]],
  "\")"
}], "Text",
  CellDingbat->"\[EmptySmallCircle]",
  CellMargins->{{66, Inherited}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Synthesis of Insertion-Sort", "Subsection"],

Cell["Problem: Synthesize A such that ", "Text"],

Cell[BoxData[
    \(\[ForAll] \+x\(\( is\[Dash]sorted\[Dash]version[x, 
          A[x]]\)\(.\)\)\)], "Input"],

Cell["Example of algorithm scheme: \"simple recursion\"", "Text"],

Cell[BoxData[
    RowBox[{\(A[\[LeftAngleBracket]\[RightAngleBracket]]\), "=", 
      StyleBox["c",
        FontFamily->"Eras Bold ITC",
        FontColor->RGBColor[1, 0, 0]]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+x A[\[LeftAngleBracket]x\[RightAngleBracket]]\), 
      "=", 
      RowBox[{
        StyleBox["s",
          FontFamily->"Eras Bold ITC",
          FontColor->RGBColor[1, 0, 0]], 
        "[", \(\[LeftAngleBracket]x\[RightAngleBracket]\), "]"}]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+\(x, y\&_\)\), 
      RowBox[{"(", 
        RowBox[{\(A[\[LeftAngleBracket]x, y\&_\[RightAngleBracket]]\), "=", 
          RowBox[{
            StyleBox["i",
              FontFamily->"Eras Bold ITC",
              FontColor->RGBColor[1, 0, 0]], "[", \(x, 
            A[\[LeftAngleBracket]y\&_\[RightAngleBracket]]\), "]"}]}], 
        ")"}]}]], "Input"],

Cell[TextData[{
  "Lazy Thinking ",
  StyleBox["automatically",
    FontColor->RGBColor[0, 0, 1]],
  " (in approx. 2 minutes on a laptop), using the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, finds the following specifications for the auxiliary functions"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["c",
        FontFamily->"Eras Bold ITC",
        FontColor->RGBColor[1, 0, 0]], 
      StyleBox["=",
        FontFamily->"Eras Bold ITC",
        FontColor->GrayLevel[0]], 
      StyleBox[\(\[LeftAngleBracket]\[RightAngleBracket]\),
        FontFamily->"Eras Bold ITC",
        FontColor->GrayLevel[0]]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+x\), 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            StyleBox["s",
              FontFamily->"Eras Bold ITC",
              FontColor->RGBColor[1, 0, 0]], 
            "[", \(\[LeftAngleBracket]x\[RightAngleBracket]\), "]"}], 
          "=", \(\[LeftAngleBracket]x\[RightAngleBracket]\)}], 
        ")"}]}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+\(x, y\&_\)\), 
      RowBox[{"(", 
        RowBox[{\(is\[Dash]sorted[\[LeftAngleBracket]y\&_\[RightAngleBracket]]\
\), " ", "\[Implies]", GridBox[{
              {
                RowBox[{"is\[Dash]sorted", "[", 
                  RowBox[{
                    StyleBox["i",
                      FontFamily->"Eras Bold ITC",
                      FontColor->RGBColor[1, 0, 0]], 
                    "[", \(x, \[LeftAngleBracket]y\&_\[RightAngleBracket]\), 
                    "]"}], "]"}]},
              {
                RowBox[{
                  RowBox[{
                    StyleBox["i",
                      FontFamily->"Eras Bold ITC",
                      FontColor->RGBColor[1, 0, 0]], 
                    "[", \(\[LeftAngleBracket]x, y\&_\[RightAngleBracket]\), 
                    "]"}], " ", "\[TildeTilde]", 
                  " ", \((x\[Cup]\[LeftAngleBracket]y\&_\[RightAngleBracket])\
\)}]}
              },
            ColumnAlignments->{Left}]}], " ", ")"}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Automation of the Method", "Subsection"],

Cell[TextData[{
  "Automated induction proving: Is available in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell["\<\
Automated analysis of failing proofs and automated generation of \"lemmata\" \
( = specifications for the subalgorithms):\
\>", "Text"],

Cell[TextData[{
  "collects temporary assumptions  T[ x0, ... ",
  StyleBox["A",
    FontColor->RGBColor[1, 0, 0]],
  " [  ],  ...  ]\nand temporary goals G[ x0, ...",
  StyleBox["m  ",
    FontColor->RGBColor[1, 0, 0]],
  "[  ",
  StyleBox["A",
    FontColor->RGBColor[1, 0, 0]],
  " [  ]  ]",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  " ]"
}], "Text",
  CellMargins->{{49.3125, Inherited}, {Inherited, Inherited}}],

Cell["and produces lemma ( = specification )", "Text"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+\(X, \  ... , \ Y, \  ... \)\), "  ", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"T", "[", " ", 
              RowBox[{"x", ",", 
                RowBox[{"...", 
                  StyleBox["Y",
                    FontSize->16,
                    FontColor->RGBColor[0, 0, 1]]}], ",", "..."}], "]"}], 
            "    ", "\[DoubleLongRightArrow]", "   ", 
            RowBox[{"G", "[", 
              RowBox[{"x", ",", 
                RowBox[{"...", 
                  RowBox[{
                    StyleBox["m",
                      FontColor->RGBColor[1, 0, 0]], 
                    StyleBox["  ",
                      FontColor->RGBColor[1, 0, 0]], "[", 
                    StyleBox["Y",
                      FontSize->16,
                      FontColor->RGBColor[0, 0, 1]], "]"}]}]}], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], "]"}]}], " ", ")"}], 
        "."}]}]], "Input"],

Cell["Details: see papers [BB 2003].", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["How far can we go with this method? ", "Subsection"],

Cell["\<\
Can we automatically synthesize algorithms for non-trivial problems?\
\>", "Text"],

Cell["\<\
Example of a non-trivial problem: construction of Gr\[ODoubleDot]bner \
bases.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Can my algorithm synthesis algorithm synthesize my own Gr\
\[ODoubleDot]bner bases algorithm",
    FontColor->RGBColor[1, 0, 0]],
  " (and similar algorithms)?"
}], "Text"],

Cell["\<\
Key of algorithmic Gr\[ODoubleDot]bner bases theory:  The \"S-polynomials\"  \
(\"critical pairs\").\
\>", "Text"],

Cell["\<\
Can we invent the notion of S-polynomials and the corresponding theorem (with \
proof) automatically?\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithmic Synthesis of My Gr\[ODoubleDot]bner Bases Algorithm ", \
"Section"],

Cell[CellGroupData[{

Cell["The Problem of Constructing Gr\[ODoubleDot]bner Bases", "Subsection"],

Cell[TextData[{
  " Find algorithm ",
  StyleBox["Gb",
    FontColor->RGBColor[0, 0, 1]],
  " such that"
}], "Text"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+F\), "    ", 
      RowBox[{"(", GridBox[{
            {
              RowBox[{"is\[Dash]finite", "[", " ", 
                RowBox[{
                  StyleBox["Gb",
                    FontColor->RGBColor[0, 0, 1]], "[", "F", "]"}], " ", 
                "]"}]},
            {
              RowBox[{"is\[Dash]Gr\[ODoubleDot]bner\[Dash]basis", "[", " ", 
                RowBox[{
                  StyleBox["Gb",
                    FontColor->RGBColor[0, 0, 1]], "[", "F", "]"}], "]"}]},
            {
              RowBox[{\(ideal[F]\), "=", 
                RowBox[{
                  RowBox[{"ideal", "[", " ", 
                    RowBox[{
                      StyleBox["Gb",
                        FontColor->RGBColor[0, 0, 1]], "[", "F", "]"}], "]"}],
                   "."}]}]}
            },
          ColumnAlignments->{Left}], ")"}]}]], "Input"],

Cell["Definitions [BB 1965, 1970]:", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["is\[Dash]Gr\[ODoubleDot]bner\[Dash]basis",
          FontColor->RGBColor[0, 0, 1]], "[", "G", "]"}], 
      "\[DoubleLeftRightArrow]", 
      RowBox[{
        RowBox[{"is\[Dash]confluent", "[", 
          StyleBox[\( \[Rule] \_G\),
            FontColor->RGBColor[1, 0, 0]], "]"}], "."}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Confluence of Division ",
  Cell[BoxData[
      StyleBox[\( \[Rule] \_G\),
        FontColor->RGBColor[1, 0, 0]]]]
}], "Subsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\((h1\( \[Rule] \_G\)h2)\), "\[DoubleLeftRightArrow]", " ", 
        RowBox[{\(\[Exists] \+\(g \[Element] G\)\), 
          RowBox[{"(", 
            RowBox[{
              StyleBox["{",
                SpanMaxSize->Infinity], GridBox[{
                  {\(lp[g] | lp[h1]\)},
                  {\(h2 = h1 - \((lm[h1]/lm[g])\)\ g\)}
                  },
                ColumnAlignments->{Left}], 
              StyleBox["}",
                ShowContents->False]}], " ", ")"}]}]}], ","}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["is\[Dash]confluent",
          FontColor->RGBColor[0, 0, 1]], "[", "\[Rule]", "]"}], " ", 
      ":", \(\(\[DoubleLeftRightArrow]\)\(\[ForAll] \+\(f1, f2\)\((f1\( \
\[LeftRightArrow] \^*\)f2 \[Implies] 
              f1\(\[DownArrow]\^*\)f2)\)\)\)}]], "Input"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0002J@0@0006`00000000000000=l1001W0@00
00000000002a;P00=BD00215CDH00040T2H00:H100030000000000000000000000@00003003n0000
b`000000000000000000033P0`3h60<02P00010000000000000000T0000@0000h04006P1000D0000
300000d0000W00006000004000000000oooo0000000U000030000040000U0000300000P0080U0000
30000040001<0000I000000000000000g`4006L10000000000000>01001X0@008@3`000000000000
0020?`00000000000020?`0000000000000000000000000000000000000000009@0000`000010000
9@0000`000000020:00000`0000100009@0000`0000700203000010000000000000004H0000X0000
700004M4BD<200008`0004L100290000H@40000000160000500000P00017A4U30`000580001`0@00
0@000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000<0040000000@000040000100000000000000000000
00010?ooo`00000P00000000000000000000000000000000000003DU000000P00000000000000000
00000000000100000@000040000100000P0000800000000000000040000100000000000000010000
00000000000000400000000000000040000004S0o`5/`?l19>XC05jlTS2000000@0006Af00P00000
9@0000`000010000600000`0000000026@0000`0003oool26`0001000000000000000180000<0000
0P0004H0000X0000700004M4BD<20000X`0004L1000m0@00H@40000000160000500000P00017A4U3
0`0001P0000<000000000QT0000<0000oooo0Q/0000@000000000000000B000030000080000<0000
4000000000000000AP0002P0000L0000AdA9@`80001b0000CP0009L0001_0000000005l0000h0000
0P0003P000000000>000000000000P400`0000000000o`0000000000000000009@0000`000020000
9@0000`000050020E`0002@0001g0000C@0009L0001Z00000P0009@0D01j06L09@0000`000080020
:00000`0000200009`0001P0000200000000003o000000009@0000`000020000EP0002P0001d0000
H@000800001/00000`0007T0H@1d06`0P01Y02D0000<00001`00P2D0000<00000000P2P0000<0000
0P0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80001F0000IP0007/000270000
000005l0000h00000P0003P000000000>000000000000P400`0000000000o`000000000000000000
9@0000`0000200009@0000`000050020E`0002@0001K0000I@0007/0002200000P0007P0J01N07l0
9@0000`000080020:00000`0000200009`0001P0000200000000003o000000009@0000`000020000
EP0002P0001H0000N@0006@0002400000`0005d0N@1H08@0I02102D0000<00001`00P2D0000<0000
0000P2P0000<00000P0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80001F0@00
KP0007/1002?0000000005l0000h00000P0003P000000000>000000000000P400`0000000000o`00
00000000000000009@0000`0000200009@0000`000050020E`0002@0001K0@00K@0007/1002:0000
0P0007P1L01N0HL09@0000`000080020:00000`0000200009`0001P0000200000000003o00000000
9@0000`000020000EP0002P0001H0@00P@0006@1002<00000`0005d1P@1H0H`0I06902D0000<0000
1`00P2D0000<00000000P2P0000<00000P0004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80003f0000>P0001/1001K0000000005l0000h00000P0003P000000000>000000000000P40
0`0000000000o`0000000000000000009@0000`0000200009@0000`000050020E`0002@0003k0000
>@0001/1001F00000P0001P1?03n05<09@0000`000080020:00000`0000200009`0001P000020000
0000003o000000009@0000`000020000EP0002P0003h0000C@0000@1001H00000`000?d0C@3h05P0
105E02D0000<00001`00P2D0000<00000000P2P0000<00000P0004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80002n0000JP000><0002;0000000005l0000h00000P0003P000000000
>000000000000P400`0000000000o`0000000000000000009@0000`0000200009@0000`000050020
E`0002@000330000J@000><0002600000P000>00K03608<09@0000`000080020:00000`000020000
9`0001P0000200000000003o000000009@0000`000020000EP0002P000300000O@000<`000280000
0`000<D0O@3008P0c02502D0000<00001`00P2D0000<00000000P2P0000<00000P0004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80003J0000DP000?l0001c0000000005l0000h0000
0P0003P000000000>000000000000P400`0000000000o`0000000000000000009@0000`000020000
9@0000`000050020E`0002@0003O0000D@000?l0001^00000P000?`0E03R06/09@0000`000080020
:00000`0000200009`0001P0000200000000003o000000009@0000`000020000EP0002P0003L0000
I@000>P0001`00000`000>40I@3L0700j01]02D0000<00001`00P2D0000<00000000P2P0000<0000
0P0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80002Z0000JP000<L0002;0000
000005l0000h00000P0003P000000000>000000000000P400`0000000000o`000000000000000000
9@0000`0000200009@0000`000050020E`0002@0002Y0000J@000<80002500000P000:`0K02o0880
9@0000`000080020:00000`0000200009`0001P0000200000000003o000000009@0000`000020000
EP0002P0002i0000O@000<@0002800000`000;T0Q03408P0`@1m02D0000<00001`00P2D0000<0000
0000P2P0000<00000P0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`8000120@00
KP0005l1002?0000000005l0000h00000P0003P000000000>000000000000P400`0000000000o`00
00000000000000009@0000`0000200009@0000`000050020E`0002@000110@00K@0005X100290000
0P0004@1L01G0HH09@0000`000080020:00000`0000200009`0001P0000200000000003o00000000
9@0000`000020000EP0002P0001A0@00P@0005`1002<00000`000541R01L0H`0F@6102D0000<0000
1`00P2D0000<00000000P2P0000<00000P0004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80000Z0@00DP0004L1001c0000000005l0000h00000P0003P000000000>000000000000P40
0`0000000000o`0000000000000000009@0000`0000200009@0000`000050020E`0002@0000Y0@00
D@000481001]00000P0002`1E00o0FX09@0000`000080020:00000`0000200009`0001P000020000
0000003o000000009@0000`000020000EP0002P0000i0@00I@0004@1001`00000`0003T1K0140G00
@@5U02D0000<00001`00P2D0000<00000000P2P0000<00000P0004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80000F0@00>P0003<1001K0000000005l0000h00000P0003P000000000
>000000000000P400`0000000000o`0000000000000000009@0000`0000200009@0000`000050020
E`0002@0000E0@00>@0002h1001E00000P0001P1?00[0E809@0000`000080020:00000`000020000
9`0001P0000200000000003o000000009@0000`000020000EP0002P0000U0@00C@000301001H0000
0`0002D1E00`0EP0;@5=02D0000<00001`00P2D0000<00000000P2P0000<00000P0004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80002B0000CP000:l0001_0000000005l0000h0000
0P0003P000000000>000000000000P400`0000000000o`0000000000000000009@0000`000020000
9@0000`000050020E`0002@0002A0000C@000:X0001Y00000P0009@0D02W06H09@0000`000080020
:00000`0000200009`0001P0000200000000003o000000009@0000`000020000EP0002P0002Q0000
H@000:`0001/00000`000:40J02/06`0Z@1Q02D0000<00001`00P2D0000<00000000P2P0000<0000
0P0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80001F0000PP0007<0002S0000
000005l0000h00000P0003P000000000>000000000000P400`000000000cc<`00000000000000000
9@0000`0000200009@0000`000050020E`0002@0001E0000P@0006h0002M00000P0005P0Q01[09X0
9@0000`000080020:00000`0000200009`0001P000020000000003?<c00000009@0000`000020000
EP0002P0001U0000U@000700002P00000`0006D0W01`0:00K@2E02D0000<00001`00P2D0000<0000
0000P2P0000<00000P0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80001^0000
WP0008/0002o0000000005l0000h00000P0003P000000000>000000000000P400`000000000cc<`0
00000000000000009@0000`0000200009@0000`000050020E`0002@0001]0000W@0008H0002i0000
0P000700X0230;H09@0000`000080020:00000`0000200009`0001P000020000000003?<c0000000
9@0000`000020000EP0002P0001m0000/@0008P0002l00000`0007d0^0280;`0Q@2a02D0000<0000
1`00P2D0000<00000000P2P0000<00000P0004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`8000220000]P0009l0003G0000000005l0000h00000P0003P000000000>000000000000P40
0`000000000cc<`000000000000000009@0000`0000200009@0000`000050020E`0002@000210000
]@0009X0003A00000P0008@0^02G0<h09@0000`000080020:00000`0000200009`0001P000020000
000003?<c00000009@0000`000020000EP0002P0002A0000b@0009`0003D00000`000940d02L0=@0
V@3902D0000<00001`00P2D0000<00000000P2P0000<00000P0004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80002F0000cP000;<0003_0000000005l0000h00000P0003P000000000
>000000000000P400`000000000cc<`000000000000000009@0000`0000200009@0000`000050020
E`0002@0002E0000c@000:h0003Y00000P0009P0d02[0>H09@0000`000080020:00000`000020000
9`0001P000020000000003?<c00000009@0000`000020000EP0002P0002U0000h@000;00003/0000
0`000:D0j02`0>`0[@3Q02D0000<00001`00P2D0000<00000000P2P0000<00000P0004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80002Z0000iP000<L000070@00000005l0000h0000
0P0003P000000000>000000000000P400`000000000cc<`000000000000000009@0000`000020000
9@0000`000050020E`0002@0002Y0000i@000<8000010@000P000:`0j02o0?h09@0000`000080020
:00000`0000200009`0001P000020000000003?<c00000009@0000`000020000EP0002P0002i0000
n@000<@000040@000`000;T0007400@1`@3i02D0000<00001`00P2D0000<00000000P2P0000<0000
0P0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80002n0000oP000=/0000O0@00
000005l0000h00000P0003P000000000>000000000000P400`000000000cc<`00000000000000000
9@0000`0000200009@0000`000050020E`0002@0002m0000o@000=H0000I0@000P000<00007C01H1
9@0000`000080020:00000`0000200009`0001P000020000000003?<c00000009@0000`000020000
EP0002P0003=00004@400=P0000L0@000`000<d0607H01`1e@0A0BD0000<00001`00P2D0000<0000
0000P2P0000<00000P0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80003B0000
5P400>l0000g0@00000005l0000h00000P0003P000000000>000000000000P400`000000000cc<`0
00000000000000009@0000`0000200009@0000`000050020E`0002@0003A00005@400>X0000a0@00
0P000=@0607W02h19@0000`000080020:00000`0000200009`0001P000020000000003?<c0000000
9@0000`000020000EP0002P0003Q0000:@400>`0000d0@000`000>40<07/03@1j@0Y0BD0000<0000
1`00P2D0000<00000000P2P0000<00000P0004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80001f0@00LP0009<1002C0000000005l0000h00000P0003P000000000>000000000000P40
0`0000000000o`0000000000000000009@0000`0000200009@0000`000050020E`0002@0001e0@00
L@0008h1002=00000P0007P1M02;0HX09@0000`000080020:00000`0000200009`0001P000020000
0000003o000000009@0000`000020000EP0002P000250@00Q@000901002@00000`0008D1S02@0I00
S@6502D0000<00001`00P2D0000<00000000P2P0000<00000P0004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80001^0@00SP0009<1002_0000000005l0000h00000P0003P000000000
>000000000000P400`000000000cc<`000000000000000009@0000`0000200009@0000`000050020
E`0002@0001c0@00S@0009<1002Z00000P000901T01f0JL09@0000`000080020:00000`000020000
9`0001P000020000000003?<c00000009@0000`000020000EP0002P0001`0@00X@0007`1002/0000
0`0007D1X@1`0J`0O06Y02D0000<00001`00P2D0000<00000000P2P0000<00000P0004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80001B0@00ZP0007L1003;0000000005l0000h0000
0P0003P000000000>000000000000P400`000000000cc<`000000000000000009@0000`000020000
9@0000`000050020E`0002@0001G0@00Z@0007L1003600000P0007@1[01J0L<09@0000`000080020
:00000`0000200009`0001P000020000000003?<c00000009@0000`000020000EP0002P0001D0@00
_@000601003800000`0005T1_@1D0LP0H07502D0000<00001`00P2D0000<00000000P2P0000<0000
0P0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80000f0@00aP0005/1003W0000
000005l0000h00000P0003P000000000>000000000000P400`000000000cc<`00000000000000000
9@0000`0000200009@0000`000050020E`0002@0000k0@00a@0005/1003R00000P0005P1b00n0Ml0
9@0000`000080020:00000`0000200009`0001P000020000000003?<c00000009@0000`000020000
EP0002P0000h0@00f@0004@1003T00000`0003d1f@0h0N@0A07Q02D0000<00001`00P2D0000<0000
0000P2P0000<00000P0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80000J0@00
gP0003l1003o0000000005l0000h00000P0003P000000000>000000000000P400`000000000cc<`0
00000000000000009@0000`0000200009@0000`000050020E`0002@0000O0@00g@0003l1003j0000
0P0003`1h00R0OL09@0000`000080020:00000`0000200009`0001P000020000000003?<c0000000
9@0000`000020000EP0002P0000L0@00l@0002P1003l00000`000241l@0L0O`0:07i02D0000<0000
1`00P2D0000<00000000P2P0000<00000P0004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`8000020@00mP0002L1000G0@00000005l0000h00000P0003P000000000>000000000000P40
0`000000000cc<`000000000000000009@0000`0000200009@0000`000050020E`0002@000070@00
m@0002L1000B0@000P0002@1n00:0@l19@0000`000080020:00000`0000200009`0001P000020000
000003?<c00000009@0000`000020000EP0002P000040@002@400101000D0@000`0000T12@440A@1
404A0BD0000<00001`00P2D0000<00000000P2P0000<00000P0004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80003V00004P4000/1000c0@00000005l0000h00000P0003P000000000
>000000000000P400`000000000cc<`000000000000000009@0000`0000200009@0000`000050020
E`0002@0003[00004@4000/1000^0@000P0000P1507^02/19@0000`000080020:00000`000020000
9`0001P000020000000003?<c00000009@0000`000020000EP0002P0003X00009@400?@0000`0@00
0`000>d09@7X0301m00]0BD0000<00001`00P2D0000<00000000P2P0000<00000P0004H0000D0000
200004M4BD<300009@0000`0000500209@0000`000080020:`0001P0000l0000M00005<0002<0000
9@0000`0000000209@0000`000070020600000`0000000026@0000`0003oool26`00010000000000
00000580001`0@000P000?3oool0000000000000002@0@000000001002910780J@1Q06`000000000
000000000000000000000000000000000000000000000000000000000000000000380=3R4`2XQlP0
oG43<000002H@0<`3`000080002TQlP0000006CS4`3K?`<`Y8O80000000DPlP0I><C0:]40c0P2@42
7C`3<2Dl0c1P0000B000060000180000T>@C060000180000H00004P00015O08`1`00060000000000
F><C098k0c070000[>@C07^PS32TQlP0H00004P0001P0000B0000:B7b03Pi1<033/3<93T4`010000
000C08Bo2GhP2@42Y><C0>@4000diA<00000008PSS0P2@42Y><C0040000diA<0c8G809SU4`000000
;@0006Af00P000009@0000`000020000:00000`000010000600000`0000000026@0000`0003oool2
6`00010000000000000001H0000<000060000180000<00000@0005@0001H0000@@0007L0001=0000
R00000400000L<I1EGGC@D40002600000P0004`00000000000000000003ooooooooooe00001V0340
100000T0000F000030000000000B000030000080000B000030000080000U0000300000D0080U0000
300000P0080[0000600009`100200000/`4009P0000U000030000000080U0000300000L0080H0000
30000000008I000030000?ooo`8K00004000000000000000600000`0000000026@0000`0003oool2
6`00010000000000000001H0000<000060000180000<00000@0005@0001H0000X@4008<0002]0@00
U00000400000L<I1EGGC@J41002B00000P0004`00000000000000000003ooooooooooe00001V0380
100000T0000F000030000000000B000030000080000B000030000080000<00004000000000000000
9@0000`0000800209@0000`0000500209@0000`0000=0020:00000`0000200003P0001@000000000
400001@0
\>"], "Graphics",
  ImageSize->{264, 197.625},
  ImageMargins->{{2, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Algorithm Scheme \"Critical Pair / Completion\"", "Subsection"],

Cell[BoxData[GridBox[{
        {
          RowBox[{
            RowBox[{
              StyleBox["A",
                FontColor->RGBColor[0, 0, 1]], "[", "F", "]"}], " ", "=", 
            RowBox[{
              StyleBox["A",
                FontColor->RGBColor[0, 0, 1]], "[", \(F, pairs[F]\), 
              "]"}]}]},
        {
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["A",
                  FontColor->RGBColor[0, 0, 1]], 
                "[", \(F, \[LeftAngleBracket]\[RightAngleBracket]\), "]"}], 
              "=", "F"}], "\[IndentingNewLine]"}]},
        {
          RowBox[{
            RowBox[{
              StyleBox["A",
                FontColor->RGBColor[0, 0, 1]], 
              "[", \(F, \[LeftAngleBracket]\[LeftAngleBracket]g1, 
                  g2\[RightAngleBracket], p\&_\[RightAngleBracket]\), "]"}], 
            "=", "\[IndentingNewLine]", 
            RowBox[{"where", "[", 
              RowBox[{
                RowBox[{"f", "=", 
                  RowBox[{
                    StyleBox["lc",
                      FontWeight->"Bold",
                      FontColor->RGBColor[1, 0, 0]], "[", \(g1, g2\), "]"}]}],
                 ",", \(h1 = trd[rd[f, g1], F]\), 
                ",", \(h2 = trd[rd[f, g2], F]\), ",", "\[IndentingNewLine]", 
                RowBox[{
                  StyleBox["{",
                    SpanMaxSize->Infinity], GridBox[{
                      {
                        RowBox[{
                          StyleBox["A",
                            FontColor->RGBColor[0, 0, 1]], 
                          "[", \(F, \[LeftAngleBracket]p\&_\
\[RightAngleBracket]\), "]"}], "\[DoubleLeftArrow]", \(h1 = h2\)},
                      {
                        RowBox[{
                          StyleBox["A",
                            FontColor->RGBColor[0, 0, 1]], "[", 
                          RowBox[{
                            RowBox[{"F", "\[Cap]", 
                              RowBox[{
                                StyleBox["df",
                                  FontWeight->"Bold",
                                  FontColor->RGBColor[1, 0, 0]], "[", \(h1, 
                                h2\), "]"}]}], ",", 
                            
                            RowBox[{\(\[LeftAngleBracket]p\&_\
\[RightAngleBracket]\), "\[CupCap]", 
                              RowBox[{"\[LeftAngleBracket]", 
                                RowBox[{
                                  RowBox[{"\[LeftAngleBracket]", 
                                    RowBox[{\(F\_k\), ",", 
                                      RowBox[{
                                        StyleBox["df",
                                        FontWeight->"Bold",
                                        FontColor->RGBColor[1, 0, 0]], 
                                        "[", \(h1, h2\), "]"}]}], 
                                    "\[RightAngleBracket]"}], \( \
\[VerticalSeparator] \+\(k = 
                                        1, \[Ellipsis], \[LeftBracketingBar]F\
\[RightBracketingBar]\)\)}], "\[RightAngleBracket]"}]}]}], "]"}], 
                        "\[DoubleLeftArrow]", "otherwise"}
                      },
                    ColumnAlignments->{Left}], 
                  StyleBox["}",
                    ShowContents->False]}]}], " ", "]"}]}]}
        },
      ColumnAlignments->{Left}]], "Input"],

Cell["\<\
This scheme can be tried in any domain, in which we have a reduction \
operation rd that depends on sets F of objects and a Noetherian relation \
\[Succeeds] which interacts with rd in the following natural way: \
\>", "Text"],

Cell[BoxData[
    \(\[ForAll] \+\(f, g\)\(\((f \[SucceedsEqual] 
            rd[f, g])\)\(.\)\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Essential Problem", "Subsection"],

Cell["\<\
The problem of synthesizing a Gr\[ODoubleDot]bner bases algorithm can now be \
also stated by asking whether starting with the proof of\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+F\), "    ", 
      RowBox[{"(", GridBox[{
            {
              RowBox[{"is\[Dash]finite", "[", " ", 
                RowBox[{
                  StyleBox["A",
                    FontColor->RGBColor[0, 0, 1]], "[", "F", "]"}], " ", 
                "]"}]},
            {
              RowBox[{"is\[Dash]Gr\[ODoubleDot]bner\[Dash]basis", "[", " ", 
                RowBox[{
                  StyleBox["A",
                    FontColor->RGBColor[0, 0, 1]], "[", "F", "]"}], "]"}]},
            {
              RowBox[{\(ideal[F]\), "=", 
                RowBox[{
                  RowBox[{"ideal", "[", " ", 
                    RowBox[{
                      StyleBox["A",
                        FontColor->RGBColor[0, 0, 1]], "[", "F", "]"}], "]"}],
                   "."}]}]}
            },
          ColumnAlignments->{Left}], ")"}]}]], "Input"],

Cell[TextData[{
  " we can ",
  StyleBox["automatically",
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox[" arrive at the idea",
    FontColor->RGBColor[1, 0, 0]],
  " that"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["lc",
          FontWeight->"Bold",
          FontColor->RGBColor[1, 0, 0]], "[", \(g1, g2\), "]"}], "=", 
      RowBox[{
        StyleBox["lcm",
          FontWeight->"Bold",
          FontColor->RGBColor[1, 0, 0]], "[", \(lp[g1], lp[g2]\), 
        "]"}]}]], "Input"],

Cell["and", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["df",
          FontWeight->"Bold",
          FontColor->RGBColor[1, 0, 0]], "[", \(h1, h2\), "]"}], "=", 
      RowBox[{"h1", 
        StyleBox["-",
          FontWeight->"Bold",
          FontColor->RGBColor[1, 0, 0]], "h2"}]}]], "Input"],

Cell["and prove that the idea is correct.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Now Start the (Automated) Correctness Proof", "Subsection"],

Cell["Details cannot be presented in one talk.", "Text"],

Cell[TextData[{
  "With current theorem proving technology, in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system, the proof attempt can be done automatically."
}], "Text"],

Cell[TextData[{
  "The proof, of course, fails at the point where it would need knowledge \
about the unknown subalgorithms ",
  StyleBox["lc",
    FontColor->RGBColor[1, 0, 0]],
  " and ",
  StyleBox["df",
    FontColor->RGBColor[1, 0, 0]],
  "."
}], "Text"],

Cell[TextData[StyleBox["Beginning of the proof:",
  FontSlant->"Italic"]], "Text"],

Cell["Let G be A[ F]. We have to prove that", "Text",
  CellMargins->{{61.3125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(is\[Dash]finite[G]\)\(,\)\)\)], "Input",
  CellMargins->{{112.625, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(\(\(ideal[F] = ideal[G]\)\(,\)\)\)], "Input",
  CellMargins->{{112.625, Inherited}, {Inherited, Inherited}}],

Cell["and", "Text",
  CellMargins->{{61.3125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    \(is\[Dash]Gr\[ODoubleDot]bner\[Dash]basis[G], \ 
    i . e . \ is\[Dash]confluent[\( \[Rule] \_G\)] . \)], "Input",
  CellMargins->{{112.625, Inherited}, {Inherited, Inherited}}],

Cell["For this, we assume", "Text",
  CellMargins->{{61.3125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[
    RowBox[{
      StyleBox["{",
        SpanMaxSize->Infinity], GridBox[{
          {\(p\( \[Rule] \_G\)f1\)},
          {\(p\( \[Rule] \_G\)\(\(f2\)\(.\)\)\)}
          },
        ColumnAlignments->{Left}], 
      StyleBox["}",
        ShowContents->False]}]], "Input",
  CellMargins->{{112.625, Inherited}, {Inherited, Inherited}}],

Cell["and have to find a polynomial g such that", "Text",
  CellMargins->{{61.3125, Inherited}, {Inherited, Inherited}}],

Cell[BoxData[GridBox[{
        {\(\(f1\(\( \[Rule] \_G\)\^*\)g\)\(,\)\)},
        {\(f2\(\( \[Rule] \_G\)\^*\)\(\(g\)\(.\)\)\)}
        },
      ColumnAlignments->{Left}]], "Input",
  CellMargins->{{112.625, Inherited}, {Inherited, Inherited}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generation of the Specification of lc", "Subsection"],

Cell[TextData[{
  "In the failing proof situation, by the ",
  StyleBox["(automated) ",
    FontColor->RGBColor[1, 0, 0]],
  "analysis algorithm sketched above, we detect that the proof could be \
completed if the unknown ",
  StyleBox["lc",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " satisfied the following property:"
}], "Text"],

Cell[BoxData[GridBox[{
        {
          RowBox[{
            RowBox[{\(lp[g1]\), "|", 
              RowBox[{
                StyleBox["lc",
                  FontWeight->"Bold",
                  FontColor->RGBColor[1, 0, 0]], "[", \(g1, g2\), "]"}]}], 
            ","}]},
        {
          RowBox[{
            RowBox[{\(lp[g2]\), "|", 
              RowBox[{
                StyleBox["lc",
                  FontWeight->"Bold",
                  FontColor->RGBColor[1, 0, 0]], "[", \(g1, g2\), "]"}]}], 
            ","}]}
        },
      ColumnAlignments->{Left}]], "Input"],

Cell[BoxData[
    RowBox[{\(\[ForAll] \+\(p, g1, g2\)\), 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox["{",
                  SpanMaxSize->Infinity], GridBox[{
                    {\(lp[g1] | p\)},
                    {\(lp[g2] | p\)}
                    },
                  ColumnAlignments->{Left}], 
                StyleBox["}",
                  ShowContents->False]}], " ", ")"}], "\[Implies]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["lc",
                    FontWeight->"Bold",
                    FontColor->RGBColor[1, 0, 0]], "[", \(g1, g2\), "]"}], 
                "|", "p"}], ")"}]}], ")"}], " ", "."}]}]], "Input"],

Cell[TextData[{
  StyleBox["Heureka!",
    FontSize->18,
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]],
  "It is clear that this specification is (only) met by"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["lc",
          FontWeight->"Bold",
          FontColor->RGBColor[1, 0, 0]], "[", \(g1, g2\), "]"}], "=", 
      RowBox[{
        RowBox[{
          StyleBox["lcm",
            FontWeight->"Bold",
            FontColor->RGBColor[1, 0, 0]], "[", \(lp[g1], lp[g2]\), "]"}], 
        "."}]}]], "Input"],

Cell["Similarly, it can be (automatically) detected that ", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["df",
          FontWeight->"Bold",
          FontColor->RGBColor[1, 0, 0]], "[", \(h1, h2\), "]"}], "=", 
      RowBox[{"h1", 
        StyleBox["-",
          FontWeight->"Bold",
          FontColor->RGBColor[1, 0, 0]], \(\(h2\)\(.\)\)}]}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusion", "Section"],

Cell["\<\
                                            

                                           Enjoy 

               intuition                  and                   formality
               
               \
\>", "Text",
  FontSize->16,
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["References", "Subsection"],

Cell[CellGroupData[{

Cell["On Gr\[ODoubleDot]bner Bases", "Subsubsection"],

Cell["\<\
[Buchberger 1970]
B. Buchberger. Ein algorithmisches Kriterium f\[UDoubleDot]r die L\
\[ODoubleDot]sbarkeit eines algebraischen Gleichungssystems (An Algorithmical \
Criterion for the Solvability of Algebraic Systems of Equations). Aequationes \
mathematicae 4/3, 1970, pp. 374-383. (English translation in: [Buchberger, \
Winkler 1998],  pp. 535 -545.) Published version of the PhD Thesis of B. \
Buchberger, University of Innsbruck, Austria, 1965.\
\>", "Text"],

Cell["\<\
[Buchberger 1998]
B. Buchberger. Introduction to Gr\[ODoubleDot]bner Bases. In: [Buchberger, \
Winkler 1998], pp.3-31.\
\>", "Text"],

Cell["\<\
[Buchberger, Winkler, 1998]
B. Buchberger, F. Winkler (eds.). Gr\[ODoubleDot]bner Bases and Applications, \
Proceedings of the International Conference \"33 Years of Gr\[ODoubleDot]bner \
Bases\", 1998, RISC, Austria, London Mathematical Society Lecture Note \
Series, Vol. 251, Cambridge University Press, 1998.\
\>", "Text"],

Cell["\<\
[Becker, Weispfenning 1993]
T. Becker, V. Weispfenning. Gr\[ODoubleDot]bner Bases: A Computational \
Approach to Commutative Algebra, Springer, New York, 1993.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["On Mathematical Knowledge Management", "Subsubsection"],

Cell["\<\
B. Buchberger, G. Gonnet, M. Hazewinkel (eds.)
Mathematical Knowledge Management.
Special Issue of Annals of Mathematics and Artificial Intelligence, Vol. 38, \
No. 1-3, May 2003, Kluwer Academic Publisher, 232 pages.\
\>", "Text"],

Cell["\<\
A.Asperti, B. Buchberger,J.H.Davenport (eds.)
Mathematical Knowledge Management.
Proceedings of the Second International Conference on Mathematical Knowledge \
Management (MKM 2003), Bertinoro, Italy, Feb.16-18, 2003, Lecture Notes in \
Computer Science, Vol.2594, Springer, Berlin-Heidelberg-NewYork, 2003, 223 \
pages.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["On Theorema", "Subsubsection"],

Cell["\<\
[Buchberger et al. 2000]
B. Buchberger, C. Dupre, T. Jebelean, F. Kriftner, K. Nakagawa, D. Vasaru, W. \
Windsteiger. The Theorema Project: A Progress Report. In: M. Kerber and M. \
Kohlhase (eds.), Symbolic Computation and Automated Reasoning (Proceedings of \
CALCULEMUS 2000, Symposium on the Integration of Symbolic Computation and \
Mechanized Reasoning, August 6-7, 2000, St. Andrews, Scotland),  A.K. Peters, \
Natick, Massachusetts, ISBN 1-56881-145-4, pp. 98-113.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["On Theory Exploration and Algorithm Synthesis", "Subsubsection"],

Cell[TextData[{
  "[Buchberger 2000] \nB. Buchberger. Theory Exploration with ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ". \nAnalele Universitatii Din Timisoara, Ser. Matematica-Informatica, Vol. \
XXXVIII, Fasc.2, 2000, (Proceedings of SYNASC 2000, 2nd International \
Workshop on Symbolic and Numeric Algorithms in Scientific Computing, Oct. \
4-6, 2000, Timisoara, Rumania, T. Jebelean, V. Negru, A. Popovici eds.), ISSN \
1124-970X, pp. 9-32. "
}], "Text"],

Cell["\<\
[Buchberger 2003] 
B. Buchberger. Algorithm Invention and Verification by Lazy Thinking.
In: D. Petcu, V. Negru, D. Zaharie, T. Jebelean (eds), Proceedings of SYNASC \
2003 (Symbolic and Numeric Algorithms for Scientific Computing, Timisoara, \
Romania, October 1\[Dash]4, 2003), Mirton Publishing, ISBN 973\[Dash]661\
\[Dash]104\[Dash]3, pp. 2\[Dash]26.\
\>", "Text"],

Cell["\<\
[Buchberger 2004]
B. Buchberger. The Four Parallel Threads of Formal Theory Exploration. \
Technical Report of the SFB (Special Research Area) Scientific Computing, \
Johannes Kepler University, Linz, in preparation.\
\>", "Text"],

Cell["\<\
[Buchberger, Craciun 2003]
B. Buchberger, A. Craciun. Algorithm Synthesis by Lazy Thinking: Examples and \
Implementation in Theorema. in: Fairouz Kamareddine (ed.),  Proc. of the \
Mathematical Knowledge Management Workshop, Edinburgh, Nov. 25, 2003, \
Electronic Notes on Theoretical Computer Science,  volume dedicated to the \
MKM 03 Symposium, Elsevier, ISBN 044451290X, to appear.\
\>", "Text"],

Cell["\<\
[Buchberger 2004]
B. Buchberger. 
Towards the Automated Synthesis of a Gr\[ODoubleDot]bner Bases Algorithm.
RACSAM (Review of the Royal Spanish Academy of Science), to appear, 10 pages.\
\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Inherited}, {None, Inherited, None}},
PageFooters->{{Inherited, Inherited, Inherited}, {Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited}},
PageHeaderLines->{Inherited, False},
PrintingOptions->{"FirstPageFooter"->False},
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    AutoItalicWords->{"Theorema"},
    LimitsPositioningTokens->{},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Arial",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Arial",
    FontSize->24,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Arial",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Arial",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Arial",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Arial",
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsubsection"],
    CellDingbat->"\[EmptySmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsubsection",
    FontFamily->"Arial",
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Open  ]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    FontFamily->"Arial"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Arial",
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Arial",
    FontSize->9,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None,
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Open  ]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9,
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic"]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Proof Cells", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProofText"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    ParagraphIndent->0,
    CounterIncrements->"Text",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["ProofText", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["ProofText", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["ProofText", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Label"],
    CellMargins->{{20, 30}, {7, 7}},
    LineSpacing->{1, 3},
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Label", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Label", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Label", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Conclusion"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Conclusion", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Conclusion", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Conclusion", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Assumption"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    FontColor->RGBColor[0.270588, 0.545098, 0.454902]],
  
  Cell[StyleData["Assumption", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Assumption", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Assumption", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Expression"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3}],
  
  Cell[StyleData["Expression", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Expression", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Expression", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Indent"],
    CellSize->{25, Inherited}],
  
  Cell[StyleData["Indent", "Presentation"],
    CellSize->{30, Inherited}],
  
  Cell[StyleData["Indent", "Condensed"],
    CellSize->{15, Inherited}],
  
  Cell[StyleData["Indent", "Printout"],
    CellSize->{15, Inherited}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Blank"],
    CellSize->{15, Inherited}],
  
  Cell[StyleData["Blank", "Presentation"],
    CellSize->{20, Inherited}],
  
  Cell[StyleData["Blank", "Condensed"],
    CellSize->{10, Inherited}],
  
  Cell[StyleData["Blank", "Printout"],
    CellSize->{10, Inherited}]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 61, 0, 48, "Text"],

Cell[CellGroupData[{
Cell[1840, 55, 124, 5, 138, "Subtitle"],
Cell[1967, 62, 203, 10, 234, "Subsubtitle"],
Cell[2173, 74, 442, 10, 210, "Text"],

Cell[CellGroupData[{
Cell[2640, 88, 38, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[2703, 92, 69, 0, 68, "Subsection"],
Cell[2775, 94, 108, 3, 48, "Text"],
Cell[2886, 99, 70, 1, 52, "Input"],
Cell[2959, 102, 76, 0, 48, "Text"],
Cell[3038, 104, 121, 2, 52, "Input"],
Cell[3162, 108, 45, 0, 48, "Text"],
Cell[3210, 110, 531, 11, 166, "Input"],
Cell[3744, 123, 258, 8, 156, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4039, 136, 105, 5, 68, "Subsection"],
Cell[4147, 143, 188, 6, 49, "Text"],
Cell[4338, 151, 137, 2, 48, "Text"],
Cell[4478, 155, 152, 2, 48, "Text"],
Cell[4633, 159, 138, 2, 48, "Text"],
Cell[4774, 163, 249, 7, 48, "Text"],
Cell[5026, 172, 134, 5, 49, "Text"],
Cell[5163, 179, 144, 5, 49, "Text"],
Cell[5310, 186, 129, 5, 49, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5488, 197, 74, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[5587, 201, 60, 0, 68, "Subsection"],
Cell[5650, 203, 47, 0, 48, "Text"],
Cell[5700, 205, 230, 7, 48, "Text"],
Cell[5933, 214, 336, 11, 56, "Text"],
Cell[6272, 227, 294, 8, 48, "Text"],
Cell[6569, 237, 411, 9, 75, "Text"],
Cell[6983, 248, 85, 2, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7105, 255, 71, 0, 68, "Subsection"],
Cell[7179, 257, 48, 0, 48, "Text"],
Cell[7230, 259, 109, 2, 52, "Input"],
Cell[7342, 263, 67, 0, 48, "Text"],
Cell[7412, 265, 1381, 32, 64, "Input"],
Cell[8796, 299, 288, 8, 76, "Text"],
Cell[9087, 309, 272, 8, 52, "Input"],
Cell[9362, 319, 920, 23, 65, "Input"],
Cell[10285, 344, 461, 12, 52, "Input"],
Cell[10749, 358, 246, 8, 49, "Text"],
Cell[10998, 368, 137, 4, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11172, 377, 74, 0, 68, "Subsection"],
Cell[11249, 379, 272, 8, 52, "Input"],
Cell[11524, 389, 920, 23, 65, "Input"],
Cell[12447, 414, 461, 12, 52, "Input"],
Cell[12911, 428, 346, 10, 75, "Text"],
Cell[13260, 440, 380, 11, 75, "Text"],
Cell[13643, 453, 327, 10, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14007, 468, 58, 0, 68, "Subsection"],
Cell[14068, 470, 48, 0, 48, "Text"],
Cell[14119, 472, 109, 2, 52, "Input"],
Cell[14231, 476, 65, 0, 48, "Text"],
Cell[14299, 478, 187, 4, 41, "Input"],
Cell[14489, 484, 297, 7, 52, "Input"],
Cell[14789, 493, 395, 9, 56, "Input"],
Cell[15187, 504, 288, 8, 76, "Text"],
Cell[15478, 514, 358, 10, 41, "Input"],
Cell[15839, 526, 378, 10, 52, "Input"],
Cell[16220, 538, 1034, 24, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17291, 567, 46, 0, 68, "Subsection"],
Cell[17340, 569, 133, 5, 49, "Text"],
Cell[17476, 576, 145, 3, 48, "Text"],
Cell[17624, 581, 427, 15, 75, "Text"],
Cell[18054, 598, 54, 0, 48, "Text"],
Cell[18111, 600, 995, 25, 54, "Input"],
Cell[19109, 627, 46, 0, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19192, 632, 58, 0, 68, "Subsection"],
Cell[19253, 634, 92, 2, 48, "Text"],
Cell[19348, 638, 102, 3, 48, "Text"],
Cell[19453, 643, 200, 5, 48, "Text"],
Cell[19656, 650, 124, 3, 48, "Text"],
Cell[19783, 655, 125, 3, 48, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[19957, 664, 85, 1, 79, "Section"],

Cell[CellGroupData[{
Cell[20067, 669, 75, 0, 68, "Subsection"],
Cell[20145, 671, 116, 5, 48, "Text"],
Cell[20264, 678, 900, 23, 88, "Input"],
Cell[21167, 703, 44, 0, 48, "Text"],
Cell[21214, 705, 360, 9, 41, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21611, 719, 151, 5, 68, "Subsection"],
Cell[21765, 726, 539, 13, 65, "Input"],

Cell[CellGroupData[{
Cell[22329, 743, 320, 7, 54, "Input"],
Cell[22652, 752, 13522, 170, 309, 13426, 167, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36223, 928, 69, 0, 68, "Subsection"],
Cell[36295, 930, 3413, 77, 238, "Input"],
Cell[39711, 1009, 236, 4, 75, "Text"],
Cell[39950, 1015, 108, 2, 55, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40095, 1022, 43, 0, 68, "Subsection"],
Cell[40141, 1024, 159, 3, 75, "Text"],
Cell[40303, 1029, 897, 23, 88, "Input"],
Cell[41203, 1054, 208, 8, 49, "Text"],
Cell[41414, 1064, 328, 10, 41, "Input"],
Cell[41745, 1076, 19, 0, 48, "Text"],
Cell[41767, 1078, 299, 9, 41, "Input"],
Cell[42069, 1089, 51, 0, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42157, 1094, 65, 0, 68, "Subsection"],
Cell[42225, 1096, 56, 0, 48, "Text"],
Cell[42284, 1098, 188, 5, 49, "Text"],
Cell[42475, 1105, 259, 9, 48, "Text"],
Cell[42737, 1116, 82, 1, 49, "Text"],
Cell[42822, 1119, 116, 1, 48, "Text"],
Cell[42941, 1122, 127, 2, 41, "Input"],
Cell[43071, 1126, 128, 2, 41, "Input"],
Cell[43202, 1130, 82, 1, 48, "Text"],
Cell[43287, 1133, 197, 3, 41, "Input"],
Cell[43487, 1138, 98, 1, 48, "Text"],
Cell[43588, 1141, 348, 10, 64, "Input"],
Cell[43939, 1153, 120, 1, 48, "Text"],
Cell[44062, 1156, 244, 5, 64, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44343, 1166, 59, 0, 68, "Subsection"],
Cell[44405, 1168, 351, 10, 75, "Text"],
Cell[44759, 1180, 585, 18, 64, "Input"],
Cell[45347, 1200, 778, 21, 65, "Input"],
Cell[46128, 1223, 211, 7, 59, "Text"],
Cell[46342, 1232, 358, 11, 41, "Input"],
Cell[46703, 1245, 67, 0, 48, "Text"],
Cell[46773, 1247, 310, 9, 41, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[47132, 1262, 29, 0, 79, "Section"],
Cell[47164, 1264, 275, 10, 276, "Text"],

Cell[CellGroupData[{
Cell[47464, 1278, 32, 0, 68, "Subsection"],

Cell[CellGroupData[{
Cell[47521, 1282, 53, 0, 62, "Subsubsection"],
Cell[47577, 1284, 473, 8, 156, "Text"],
Cell[48053, 1294, 142, 4, 75, "Text"],
Cell[48198, 1300, 336, 6, 129, "Text"],
Cell[48537, 1308, 183, 4, 102, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48757, 1317, 61, 0, 62, "Subsubsection"],
Cell[48821, 1319, 241, 5, 129, "Text"],
Cell[49065, 1326, 344, 7, 156, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49446, 1338, 36, 0, 62, "Subsubsection"],
Cell[49485, 1340, 496, 8, 183, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50018, 1353, 70, 0, 62, "Subsubsection"],
Cell[50091, 1355, 472, 9, 157, "Text"],
Cell[50566, 1366, 378, 7, 156, "Text"],
Cell[50947, 1375, 240, 5, 102, "Text"],
Cell[51190, 1382, 410, 7, 156, "Text"],
Cell[51603, 1391, 211, 6, 129, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

